Data classes
===============================================

.. autoclass:: b2sdk.v2.FileVersion
   :inherited-members:
   :special-members: __dict__

.. autoclass:: b2sdk.v2.DownloadVersion
   :inherited-members:

.. autoclass:: b2sdk.v2.FileIdAndName
   :inherited-members:
   :special-members: __dict__

.. autoclass:: b2sdk.v2.UnfinishedLargeFile()
   :no-members:

.. autoclass:: b2sdk.v2.Part
   :no-members:

.. autoclass:: b2sdk.v2.Range
   :no-members:
   :special-members: __init__
